---
title: <span class="badge builder"></span> NavbarPreference
---
# <span class="badge builder"></span> NavbarPreference

## Constructor

```python
NavbarPreference()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> preferences.NavbarPreference
```

### <span class="badge object-method"></span> bookmark_urls

```python
def bookmark_urls(bookmark_urls: list[str]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [NavbarPreference](./object-NavbarPreference.md)
